@@ -7,10 +7,6 @@ tmuxp.cli
 :copyright: Copyright 2013 Tony Narlock.
 :license: BSD, see LICENSE for details
 
-
-prompt, prompt_bool, prompt_choices
-LICENSE: https://github.com/techniq/flask-script/blob/master/LICENSE
-
 """
 
 import os
@@ -18,7 +14,6 @@ import sys
 import argparse
 import argcomplete
 import logging
-import pkg_resources
 import kaptan
 from . import log, util, exc, WorkspaceBuilder, Server, config
 from .util import ascii_lowercase, input
@@ -26,7 +21,15 @@ from .workspacebuilder import freeze
 from distutils.util import strtobool
 
 
-__version__ = pkg_resources.require("tmuxp")[0].version
+import re
+VERSIONFILE = os.path.join(os.path.abspath(os.path.dirname(__file__)), '__init__.py')
+verstrline = open(VERSIONFILE, "rt").read()
+VSRE = r"^__version__ = ['\"]([^'\"]*)['\"]"
+mo = re.search(VSRE, verstrline, re.M)
+if mo:
+    __version__ = mo.group(1)
+#import pkg_resources
+#__version__ = pkg_resources.require("tmuxp")[0].version
 
 logger = logging.getLogger(__name__)
 
@@ -39,6 +42,13 @@ teamocil_config_dir = os.path.expanduser('~/.teamocil/')
 def prompt(name, default=None):
     """Return user input from command line.
 
+    :meth:`~prompt`, :meth:`~prompt_bool` and :meth:`prompt_choices` are from
+    `flask-script`_. See the `flask-script license`_.
+
+    .. _flask-script: https://github.com/techniq/flask-script
+    .. _flask-script license:
+        https://github.com/techniq/flask-script/blob/master/LICENSE
+
     :param name: prompt text
     :param default: default value if no input provided.
     :rtype: string
@@ -56,8 +66,7 @@ def prompt(name, default=None):
 
 
 def prompt_bool(name, default=False, yes_choices=None, no_choices=None):
-    """
-    Return user input from command line and converts to boolean value.
+    """Return user input from command line and converts to boolean value.
 
     :param name: prompt text
     :param default: default value if no input provided.
@@ -132,9 +141,10 @@ def prompt_choices(name, choices, default=None, resolve=ascii_lowercase,
 
 class ConfigFileCompleter(argcomplete.completers.FilesCompleter):
 
-    """ argcomplete completer for tmuxp files. """
+    """argcomplete completer for tmuxp files."""
 
     def __call__(self, prefix, **kwargs):
+
         completion = argcomplete.completers.FilesCompleter.__call__(
             self, prefix, **kwargs
         )
@@ -147,7 +157,7 @@ class ConfigFileCompleter(argcomplete.completers.FilesCompleter):
 
 class TmuxinatorCompleter(argcomplete.completers.FilesCompleter):
 
-    """ argcomplete completer for Tmuxinator files. """
+    """argcomplete completer for Tmuxinator files."""
 
     def __call__(self, prefix, **kwargs):
         completion = argcomplete.completers.FilesCompleter.__call__(
@@ -164,7 +174,7 @@ class TmuxinatorCompleter(argcomplete.completers.FilesCompleter):
 
 class TeamocilCompleter(argcomplete.completers.FilesCompleter):
 
-    """ argcomplete completer for Teamocil files. """
+    """argcomplete completer for Teamocil files."""
 
     def __call__(self, prefix, **kwargs):
         completion = argcomplete.completers.FilesCompleter.__call__(
@@ -178,9 +188,14 @@ class TeamocilCompleter(argcomplete.completers.FilesCompleter):
         return completion
 
 
-def SessionCompleter(prefix, **kwargs):
-    """ Return list of session names for argcomplete completer. """
-    t = Server()
+def SessionCompleter(prefix, parsed_args, **kwargs):
+    """Return list of session names for argcomplete completer."""
+
+    t = Server(
+        socket_name=parsed_args.socket_name,
+        socket_path=parsed_args.socket_path
+    )
+
     return [s.get('session_name') for s in t._sessions
             if s.get('session_name').startswith(prefix)]
 
@@ -216,13 +231,13 @@ def startup(config_dir):
 
 
 def load_workspace(config_file, args):
-    """ Build config workspace.
+    """Build config workspace.
 
     :param config_file: full path to config file
     :param type: string
 
     """
-    logger.info('building %s.' % config_file)
+    logger.info('Loading %s.' % config_file)
 
     sconfig = kaptan.Kaptan()
     sconfig = sconfig.import_config(config_file).get()
@@ -265,7 +280,7 @@ def load_workspace(config_file, args):
             else:
                 builder.session.attach_session()
         return
-    except Exception as e:
+    except exc.TmuxpException as e:
         import traceback
 
         print(traceback.format_exc())
@@ -289,18 +304,8 @@ def load_workspace(config_file, args):
             sys.exit()
 
 
-def get_server_from_args(args):
-    """ Return a :class:`Server` object from the argparse response.
-
-    tmuxp allows flags such as -L, -S, -2 and -8.
-    may delete. sec
-
-    """
-    pass
-
-
 def command_freeze(args):
-    """ Import teamocil config to tmuxp format. """
+    """Import teamocil config to tmuxp format."""
 
     ctext = ' '.join(args.session_name)
 
@@ -364,12 +369,12 @@ def command_freeze(args):
 
 
 def command_load(args):
-    """ Load a session from a tmuxp session file. """
+    """Load a session from a tmuxp session file."""
     if args.list:
         startup(config_dir)
         configs_in_user = config.in_dir(config_dir)
         configs_in_cwd = config.in_cwd()
-        print(configs_in_cwd)
+
         sys.exit()
 
         output = ''
@@ -387,6 +392,7 @@ def command_load(args):
             )
 
         print(output)
+        return
 
     elif args.config:
         if '.' == args.config:
@@ -399,9 +405,7 @@ def command_load(args):
             configfile = args.config
         file_user = os.path.join(config_dir, configfile)
         file_cwd = os.path.join(cwd_dir, configfile)
-        print(file_user)
-        print(file_cwd)
-        print(cwd_dir)
+
         if os.path.exists(file_cwd) and os.path.isfile(file_cwd):
             print('load %s' % file_cwd)
             load_workspace(file_cwd, args)
@@ -412,34 +416,34 @@ def command_load(args):
 
 
 def command_import_teamocil(args):
-    """ Import teamocil config to tmuxp format. """
+    """Import teamocil config to tmuxp format."""
 
     if args.list:
-            try:
-                configs_in_user = config.in_dir(
-                    teamocil_config_dir, extensions='yml')
-            except OSError:
-                configs_in_user = []
-            configs_in_cwd = config.in_dir(
-                config_dir=cwd_dir, extensions='yml')
+        try:
+            configs_in_user = config.in_dir(
+                teamocil_config_dir, extensions='yml')
+        except OSError:
+            configs_in_user = []
+        configs_in_cwd = config.in_dir(
+            config_dir=cwd_dir, extensions='yml')
 
-            output = ''
+        output = ''
 
-            if not os.path.exists(teamocil_config_dir):
-                output += '# %s: \n\tDirectory doesn\'t exist.\n' % teamocil_config_dir
-            elif not configs_in_user:
-                output += '# %s: \n\tNone found.\n' % teamocil_config_dir
-            else:
-                output += '# %s: \n\t%s\n' % (
-                    config_dir, ', '.join(configs_in_user)
-                )
+        if not os.path.exists(teamocil_config_dir):
+            output += '# %s: \n\tDirectory doesn\'t exist.\n' % teamocil_config_dir
+        elif not configs_in_user:
+            output += '# %s: \n\tNone found.\n' % teamocil_config_dir
+        else:
+            output += '# %s: \n\t%s\n' % (
+                config_dir, ', '.join(configs_in_user)
+            )
 
-            if configs_in_cwd:
-                output += '# current directory:\n\t%s' % (
-                    ', '.join(configs_in_cwd)
-                )
+        if configs_in_cwd:
+            output += '# current directory:\n\t%s' % (
+                ', '.join(configs_in_cwd)
+            )
 
-            print(output)
+        print(output)
     elif args.config:
         configfile = os.path.abspath(os.path.relpath(
             os.path.expanduser(args.config)))
@@ -499,7 +503,7 @@ def command_import_teamocil(args):
 
 
 def command_import_tmuxinator(args):
-    """ Import tmuxinator config to tmuxp format. """
+    """Import tmuxinator config to tmuxp format."""
     if args.list:
             try:
                 configs_in_user = config.in_dir(
@@ -586,11 +590,11 @@ def command_import_tmuxinator(args):
 
 
 def command_convert(args):
-    """ Convert tmuxp config to and from JSON and YAML. """
+    """Convert tmuxp config to and from JSON and YAML."""
 
     try:
         configfile = args.config
-    except Exception:
+    except exc.TmuxpException:
         print('Please enter a config')
 
     file_user = os.path.join(config_dir, configfile)
@@ -634,7 +638,7 @@ def command_convert(args):
 
 
 def command_attach_session(args):
-    """ Command to attach / switch client to a tmux session."""
+    """Command to attach / switch client to a tmux session."""
     commands = []
     ctext = ' '.join(args.session_name)
 
@@ -648,8 +652,8 @@ def command_attach_session(args):
         session = next((s for s in t.sessions if s.get(
             'session_name') == ctext), None)
         if not session:
-            raise Exception('Session not found.')
-    except Exception as e:
+            raise exc.TmuxpException('Session not found.')
+    except exc.TmuxpException as e:
         print(e.message)
         return
 
@@ -663,7 +667,7 @@ def command_attach_session(args):
 
 
 def command_kill_session(args):
-    """ Command to kill a tmux session."""
+    """Command to kill a tmux session."""
     commands = []
     ctext = ' '.join(args.session_name)
 
@@ -676,162 +680,53 @@ def command_kill_session(args):
         session = next((s for s in t.sessions if s.get(
             'session_name') == ctext), None)
         if not session:
-            raise Exception('Session not found.')
-    except Exception as e:
-        print(e.message)
+            raise exc.TmuxpException('Session not found.')
+    except exc.TmuxpException as e:
+        print(e.getMessage())
         return
 
     try:
         session.kill_session()
         print("Killed session %s." % ctext)
-    except Exception as e:
+    except exc.TmuxpException as e:
         logger.error(e)
 
-
 def get_parser():
-    """ Return :py:class:`argparse.ArgumentParser` instance for CLI. """
+    """Return :py:class:`argparse.ArgumentParser` instance for CLI."""
+
+    server_parser = argparse.ArgumentParser(add_help=False)
+
+    # server_parser.add_argument(
+        # '--log-level',
+        # dest='log_level',
+        # default='INFO',
+        # metavar='log-level',
+        # help='Log level e.g. INFO, DEBUG, ERROR'
+    # )
+
+    server_parser.add_argument(
+        '-L', dest='socket_name',
+        default=None,
+        help='socket name of tmux server. Same as tmux.',
+        metavar='socket-name'
+    )
+
+    server_parser.add_argument(
+        '-S',
+        dest='socket_path',
+        default=None,
+        help='socket path of tmux server. Same as tmux.',
+        metavar='socket-path'
+    )
 
     parser = argparse.ArgumentParser(
-        description='''\
-        Launch tmux workspace. Help documentation: <http://tmuxp.rtfd.org>.
-        ''',
+        description='Launch tmux workspace. '
+                    'Help documentation: <http://tmuxp.rtfd.org>.',
+        parents=[server_parser]
     )
 
-    subparsers = parser.add_subparsers(title='commands',
-                                       description='valid commands',
-                                       help='additional help')
-
-    kill_session = subparsers.add_parser('kill-session')
-    kill_session.set_defaults(callback=command_kill_session)
-
-    kill_session.add_argument(
-        dest='session_name',
-        type=str,
-        nargs='+',
-        default=None,
-        help='Name of session',
-    ).completer = SessionCompleter
-
-    attach_session = subparsers.add_parser('attach-session')
-    attach_session.set_defaults(callback=command_attach_session)
-
-    attach_session.add_argument(
-        dest='session_name',
-        nargs='+',
-        type=str,
-        help='Name of session',
-    ).completer = SessionCompleter
-
-    freeze = subparsers.add_parser('freeze')
-    freeze.set_defaults(callback=command_freeze)
-
-    freeze.add_argument(
-        dest='session_name',
-        type=str,
-        nargs='+',
-        help='Name of session',
-    ).completer = SessionCompleter
-
-    load = subparsers.add_parser('load')
-
-    loadgroup = load.add_mutually_exclusive_group(required=True)
-    loadgroup.add_argument(
-        '--list', dest='list', action='store_true',
-        help='List config files available',
-    )
-
-    loadgroup.add_argument(
-        dest='config',
-        type=str,
-        nargs='?',
-        help='''\
-        List of config files to launch session from.
-
-        Checks current working directory (%s) then $HOME/.tmuxp directory (%s).
-
-            $ tmuxp .
-
-        will check launch a ~/.pullv.yaml / ~/.pullv.json from the cwd.
-        will also check for any ./*.yaml and ./*.json.
-        ''' % (cwd_dir + '/', config_dir),
-    ).completer = ConfigFileCompleter(allowednames=('.yaml', '.json'), directories=False)
-    load.set_defaults(callback=command_load)
-
-    convert = subparsers.add_parser('convert')
-
-    convert.add_argument(
-        dest='config',
-        type=str,
-        default=None,
-        help='''\
-        Checks current working directory (%s) then $HOME/.tmuxp directory (%s).
-
-            $ tmuxp .
-
-        will check launch a ~/.pullv.yaml / ~/.pullv.json from the cwd.
-        will also check for any ./*.yaml and ./*.json.
-        ''' % (cwd_dir + '/', config_dir)
-    ).completer = ConfigFileCompleter(allowednames=('.yaml', '.json'), directories=False)
-
-    convert.set_defaults(callback=command_convert)
-
-    importparser = subparsers.add_parser('import')
-    importsubparser = importparser.add_subparsers(title='commands',
-                                                  description='valid commands',
-                                                  help='additional help')
-
-    import_teamocil = importsubparser.add_parser('teamocil')
-
-    import_teamocilgroup = import_teamocil.add_mutually_exclusive_group(
-        required=True)
-    import_teamocilgroup.add_argument(
-        '--list', dest='list', action='store_true',
-        help='List yaml configs in ~/.teamocil and current working directory.'
-    )
-
-    import_teamocilgroup.add_argument(
-        dest='config',
-        type=str,
-        nargs='?',
-        help='''\
-        Checks current ~/.teamocil and current directory for yaml files.
-        '''
-    ).completer = TeamocilCompleter(allowednames=('.yml'), directories=False)
-    import_teamocil.set_defaults(callback=command_import_teamocil)
-
-    import_tmuxinator = importsubparser.add_parser('tmuxinator')
-
-    import_tmuxinatorgroup = import_tmuxinator.add_mutually_exclusive_group(
-        required=True)
-    import_tmuxinatorgroup.add_argument(
-        '--list', dest='list', action='store_true',
-        help='List yaml configs in ~/.tmuxinator and current working directory.'
-    )
-
-    import_tmuxinatorgroup.add_argument(
-        dest='config',
-        type=str,
-        nargs='?',
-        help='''\
-        Checks current ~/.tmuxinator and current directory for yaml files.
-        '''
-    ).completer = TmuxinatorCompleter(allowednames=('.yml'), directories=False)
-
-    import_tmuxinator.set_defaults(callback=command_import_tmuxinator)
-
-    parser.add_argument('--log-level', dest='log_level', default='INFO',
-                        metavar='log-level',
-                        help='Log level e.g. INFO, DEBUG, ERROR')
-
-    parser.add_argument('-L', dest='socket_name', default=None,
-                        help='socket name of tmux server. Same as tmux.',
-                        metavar='socket-name')
-
-    parser.add_argument('-S', dest='socket_path', default=None,
-                        help='socket path of tmux server. Same as tmux.',
-                        metavar='socket-path')
-
-    colorsgroup = parser.add_mutually_exclusive_group()
+    client_parser = argparse.ArgumentParser(add_help=False)
+    colorsgroup = client_parser.add_mutually_exclusive_group()
 
     colorsgroup.add_argument(
         '-2',
@@ -851,6 +746,147 @@ def get_parser():
 
     parser.set_defaults(colors=None)
 
+    subparsers = parser.add_subparsers(
+        title='commands',
+        description='valid commands',
+    )
+
+    kill_session = subparsers.add_parser(
+        'kill-session',
+        parents=[server_parser],
+        help='Kill tmux session by name.'
+    )
+    kill_session.set_defaults(callback=command_kill_session)
+
+    kill_session.add_argument(
+        dest='session_name',
+        type=str,
+        nargs='+',
+        default=None,
+        help='Name of session',
+    ).completer = SessionCompleter
+
+    attach_session = subparsers.add_parser(
+        'attach-session',
+        parents=[server_parser, client_parser],
+        help='If run from outside tmux, create a new client in the current '
+             'terminal and attach it. If used from inside, switch the current '
+             'client.'
+    )
+    attach_session.set_defaults(callback=command_attach_session)
+
+    attach_session.add_argument(
+        dest='session_name',
+        nargs='+',
+        type=str,
+        help='Name of session',
+    ).completer = SessionCompleter
+
+    freeze = subparsers.add_parser(
+        'freeze',
+        parents=[server_parser],
+        help='Create a snapshot of a tmux session and save it to JSON or YAML.'
+    )
+    freeze.set_defaults(callback=command_freeze)
+
+    freeze.add_argument(
+        dest='session_name',
+        type=str,
+        nargs='+',
+        help='Name of session',
+    ).completer = SessionCompleter
+
+    load = subparsers.add_parser(
+        'load',
+        parents=[server_parser, client_parser],
+        help='Load a configuration from file. Attach the session. If session '
+             'already exists, offer to attach instead.'
+    )
+
+    loadgroup = load.add_mutually_exclusive_group(required=True)
+    loadgroup.add_argument(
+        '--list', dest='list', action='store_true',
+        help='List config files available',
+    )
+
+    loadgroup.add_argument(
+        dest='config',
+        type=str,
+        nargs='?',
+        help='List config available in working directory and config folder.'
+    ).completer = ConfigFileCompleter(allowednames=('.yaml', '.json'), directories=False)
+    load.set_defaults(callback=command_load)
+
+    convert = subparsers.add_parser(
+        'convert',
+        help='Convert tmuxp config between YAML and JSON format.'
+    )
+
+    convert.add_argument(
+        dest='config',
+        type=str,
+        default=None,
+        help='Absolute or relative path to config file.'
+    ).completer = ConfigFileCompleter(allowednames=('.yaml', '.json'), directories=False)
+
+    convert.set_defaults(callback=command_convert)
+
+    importparser = subparsers.add_parser(
+        'import',
+        help='Import configurations from teamocil and tmuxinator.'
+    )
+    importsubparser = importparser.add_subparsers(
+        title='commands',
+        description='valid commands',
+        help='additional help'
+    )
+
+    import_teamocil = importsubparser.add_parser(
+        'teamocil',
+        help="Parse teamocil configurations into tmuxp format"
+    )
+
+    import_teamocilgroup = import_teamocil.add_mutually_exclusive_group(
+        required=True
+    )
+    import_teamocilgroup.add_argument(
+        '--list', dest='list', action='store_true',
+        help='List configs in ~/.teamocil and current working directory.'
+    )
+
+    import_teamocilgroup.add_argument(
+        dest='config',
+        type=str,
+        nargs='?',
+        help='''\
+        Checks current ~/.teamocil and current directory for yaml files.
+        '''
+    ).completer = TeamocilCompleter(allowednames=('.yml'), directories=False)
+    import_teamocil.set_defaults(callback=command_import_teamocil)
+
+    import_tmuxinator = importsubparser.add_parser(
+        'tmuxinator',
+        help="Parse teamocil configurations into tmuxp format"
+    )
+
+    import_tmuxinatorgroup = import_tmuxinator.add_mutually_exclusive_group(
+        required=True)
+    import_tmuxinatorgroup.add_argument(
+        '--list', dest='list', action='store_true',
+        help='List yaml configs in ~/.tmuxinator and current working directory.'
+    )
+
+    import_tmuxinatorgroup.add_argument(
+        dest='config',
+        type=str,
+        nargs='?',
+        help='''\
+        Checks current ~/.tmuxinator and current directory for yaml files.
+        '''
+    ).completer = TmuxinatorCompleter(allowednames=('.yml'), directories=False)
+
+    import_tmuxinator.set_defaults(callback=command_import_tmuxinator)
+
     # http://stackoverflow.com/questions/8521612/argparse-optional-subparser
     parser.add_argument(
         '-v', '--version', action='version',
@@ -869,11 +905,11 @@ def main():
 
     args = parser.parse_args()
 
-    setup_logger(level=args.log_level.upper())
+    setup_logger(level=args.log_level.upper() if 'log_level' in args else 'INFO')
 
     try:
-        util.version()
-    except Exception as e:
+        util.has_required_tmux_version()
+    except exc.TmuxpException as e:
         logger.error(e)
         sys.exit()
 
