@@ -3,7 +3,6 @@ from __future__ import absolute_import, division, print_function, with_statement
 
 import os
 import sys
-import unittest
 import logging
 import time
 import kaptan
@@ -19,7 +18,7 @@ example_dir = os.path.abspath(os.path.join(current_dir, '..', '..'))
 
 class FreezeTest(TmuxTestCase):
 
-    yaml_config = '''
+    yaml_config = """
     session_name: sampleconfig
     start_directory: '~'
     windows:
@@ -41,7 +40,7 @@ class FreezeTest(TmuxTestCase):
       panes:
       - shell_command:
         - htop
-    '''
+    """
 
     def test_focus(self):
         # assure the built yaml config has focus
@@ -61,7 +60,7 @@ class FreezeTest(TmuxTestCase):
         session = self.session
         sconf = freeze(session)
 
-        config.check_consistency(sconf)
+        config.validate_schema(sconf)
 
         sconf = config.inline(sconf)
 
@@ -74,6 +73,3 @@ class FreezeTest(TmuxTestCase):
 
         #logger.error(json)
         #logger.error(yaml)
-
-if __name__ == '__main__':
-    unittest.main()
